@@ -30,6 +30,6 @@ gzip -d <"$1" | {
 
 rm -fr $MANGLEDIR
 
-echo Complete with:  mv "$1.mangled" "$1"
+echo Complete with:  mv "$1.mangled" "$1.bz2"
 
 exit 0
